[cp-patches] FYI: DefaultComboBoxModel - fix for bug 26951

2006-03-31 Thread David Gilbert
This patch (committed) changes (slightly) our implementation of DefaultComboBoxModel 
to match some observed behaviours in Sun's implementation - see bug 26951 for details:


2006-03-31  David Gilbert  [EMAIL PROTECTED]

Fixes bug #26951
* javax/swing/DefaultComboBoxModel.java
(DefaultComboBoxModel(Vector)): Call getSize() instead of
vector.size(),
(addElement): Call list.addElement() rather than list.add(), and only
update selected item if it is currently null,
(removeElementAt): Update selected item, then remove the element.

Regards,

Dave
Index: javax/swing/DefaultComboBoxModel.java
===
RCS file: /sources/classpath/classpath/javax/swing/DefaultComboBoxModel.java,v
retrieving revision 1.14
diff -u -r1.14 DefaultComboBoxModel.java
--- javax/swing/DefaultComboBoxModel.java   11 Oct 2005 20:44:30 -  
1.14
+++ javax/swing/DefaultComboBoxModel.java   31 Mar 2006 09:40:03 -
@@ -1,5 +1,5 @@
 /* DefaultComboBoxModel.java --
-   Copyright (C) 2002, 2004, 2005 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2004, 2005, 2006, Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -107,22 +107,24 @@
   public DefaultComboBoxModel(Vector vector)
   {
 this.list = vector;
-if (vector.size()  0)
+if (getSize()  0)
   selectedItem = vector.get(0);
   }
 
   /**
* Adds an element to the model's item list and sends a [EMAIL PROTECTED] 
ListDataEvent}
* to all registered listeners.  If the new element is the first item added
-   * to the list, it is set as the selected item.
+   * to the list, and the selected item is codenull/code, the new element 
+   * is set as the selected item.
*
* @param object item to add to the model's item list.
*/
   public void addElement(Object object)
   {
-list.add(object);
-fireIntervalAdded(this, list.size() - 1, list.size() - 1);
-if (list.size() == 1)
+list.addElement(object);
+int index = list.size() - 1;
+fireIntervalAdded(this, index, index);
+if (list.size() == 1  selectedItem == null)
   setSelectedItem(object);
   }
 
@@ -141,14 +143,14 @@
   public void removeElementAt(int index)
   {
 int selected = getIndexOf(selectedItem);
-list.remove(index);
 if (selected == index) // choose a new selected item
   {
 if (selected  0)
   selectedItem = getElementAt(selected - 1);
 else 
-  selectedItem = getElementAt(selected);
+  selectedItem = getElementAt(selected + 1);
   }
+list.removeElementAt(index);
 fireIntervalRemoved(this, index, index);
   }
 


[cp-patches] FYI: JTable selection repainting fix

2006-03-31 Thread Audrius Meskauskas

When the table selection changes, only the area when the selection changes
requires repainting - not the whole table as it is done now. This patch
implements repainting of the changes sections only. This makes the
navigation with the arrow keys faster, as the table is no longer repainted
after just moving to the adjacent row/column.

2006-03-31  Audrius Meskauskas  [EMAIL PROTECTED]

   * javax/swing/DefaultListSelectionModel.java (fireDifference):
   New method. (clearSelection): Rewritten. (setSelectionInterval):
   Fire the difference between current and new selection.
   * javax/swing/JTable.java (columnSelectionChanged, valueChanged):
   Only repaint the region, where selection has been changed.
   * javax/swing/plaf/basic/BasicTableUI.java
   (TableAction.actionPerformed): Do not change the column selection
   when only row selection change is wanted (and in reverse) and
   do not call the repaint() here.
Index: javax/swing/JTable.java
===
RCS file: /sources/classpath/classpath/javax/swing/JTable.java,v
retrieving revision 1.91
diff -u -r1.91 JTable.java
--- javax/swing/JTable.java	30 Mar 2006 20:53:42 -	1.91
+++ javax/swing/JTable.java	31 Mar 2006 09:45:31 -
@@ -1872,13 +1872,33 @@
   }
   
   /**
-   * Invoked when the the column selection changes.
+   * Invoked when the the column selection changes, repaints the changed
+   * columns. It is not recommended to override this method, register the
+   * listener instead.
*/
   public void columnSelectionChanged (ListSelectionEvent event)
   {
-repaint();
+// Does not make sense for the table with the single column.
+if (getColumnCount()  2)
+  return;
+
+int x0 = 0;
+
+int idx0 = event.getFirstIndex();
+int idxn = event.getLastIndex();
+int i;
+
+for (i = 0; i  idx0; i++)
+  x0 += columnModel.getColumn(i).getWidth();
+
+int xn = x0;
+
+for (i = idx0; i = idxn; i++)
+  xn += columnModel.getColumn(i).getWidth();
+
+repaint(x0, 0, xn, getHeight());
   }
-  
+ 
   /**
* Invoked when the editing is cancelled.
*/
@@ -1937,11 +1957,19 @@
   }
 
   /**
-   * Invoked when another table row is selected.
+   * Invoked when another table row is selected. It is not recommended
+   * to override 

[cp-patches] FYI: Optimized painting for Swing

2006-03-31 Thread Roman Kennke
Hi there,

I optimized the painting in Swing again. This time I implemented special
algorithms for paintChildren() for the two cases when children can
overlap and when they are guaranteed to not overlap
(optimizedDrawingEnabled property).

When children can overlap (optimizedDrawingEnabled == false), then this
basically goes from top (visually) to the bottom in the child component
stack and computes the rectangles that must be painted for each child.
This is done in a way, so that areas from underlying components which
are covered by upper components are not painted. This can lead to 'split
up' areas, where we get more than one rectangle for a child component.
This has the effect that we really only paint what's necessary and
nothing more. This (for example) boosts internal frame dragging with
overlap significantly.

When children are guaranteed to be tiled (optimizedDrawingEnabled ==
true), this is even simpler, I have implemented it to figure out all the
components that are visible inside the painting rectangle. No need to
consider overlapping and splitting rectangles here.

I have tried everything in our Swing demo, the SwingSet2 demo and a
couple of other applications and have not seen any regressions yet.
Also, it doesn't appear slower (you know, there is always the
possibility that the overhead of making an optimization eats the
optimization away) in any cases, so I checked this in like this:

2006-03-31  Roman Kennke  [EMAIL PROTECTED]

* javax/swing/JComponent.java
(paintChildren): Split up in two cases, depending on the
optimizedDrawingEnabled flag.
(paintChildrenWithOverlap): New method. Paints children when
not optimizedDrawingEnabled. This implements better painting
algorithm for overlapping components, so that the painted
regions are minimized.
(paintChildrenOptimized): New method. Paints children when
when optimizedDrawingEnabled. This implements a painting
algorithm that is optimized for the case when all children
are guaranteed to be tiled.

/Roman
-- 
“Improvement makes straight roads, but the crooked roads, without
Improvement, are roads of Genius.” - William Blake
Index: javax/swing/JComponent.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/JComponent.java,v
retrieving revision 1.109
diff -u -1 -0 -r1.109 JComponent.java
--- javax/swing/JComponent.java	23 Mar 2006 23:22:39 -	1.109
+++ javax/swing/JComponent.java	31 Mar 2006 12:23:30 -
@@ -63,20 +63,21 @@
 import java.awt.event.FocusEvent;
 import java.awt.event.FocusListener;
 import java.awt.event.KeyEvent;
 import java.awt.event.MouseEvent;
 import java.awt.peer.LightweightPeer;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.beans.PropertyVetoException;
 import java.beans.VetoableChangeListener;
 import java.io.Serializable;
+import java.util.ArrayList;
 import java.util.EventListener;
 import java.util.Hashtable;
 import java.util.Locale;
 import java.util.Set;
 
 import javax.accessibility.Accessible;
 import javax.accessibility.AccessibleContext;
 import javax.accessibility.AccessibleExtendedComponent;
 import javax.accessibility.AccessibleKeyBinding;
 import javax.accessibility.AccessibleRole;
@@ -1638,53 +1639,251 @@
* component's body and border.
*
* @param g The graphics context with which to paint the children
*
* @see #paint
* @see #paintBorder
* @see #paintComponent
*/
   protected void paintChildren(Graphics g)
   {
+if (getComponentCount()  0)
+  {
+if (isOptimizedDrawingEnabled())
+  paintChildrenOptimized(g);
+else
+  paintChildrenWithOverlap(g);
+  }
+  }
+
+  /**
+   * Paints the children of this JComponent in the case when the component
+   * is not marked as optimizedDrawingEnabled, that means the container cannot
+   * guarantee that it's children are tiled. For this case we must
+   * perform a more complex optimization to determine the minimal rectangle
+   * to be painted for each child component.
+   *
+   * @param g the graphics context to use
+   */
+  private void paintChildrenWithOverlap(Graphics g)
+  {
+Shape originalClip = g.getClip();
+Rectangle inner = SwingUtilities.calculateInnerArea(this, rectCache);
+g.clipRect(inner.x, inner.y, inner.width, inner.height);
+Component[] children = getComponents();
+
+// Find the rectangles that need to be painted for each child component.
+// We push on this list arrays that have the Rectangles to be painted as
+// the first elements and the component to be painted as the last one.
+// Later we go through that list in reverse order and paint the rectangles.
+ArrayList paintRegions = new ArrayList(children.length);
+ArrayList paintRectangles = new ArrayList();
+ArrayList newPaintRects = new ArrayList();
+

[cp-patches] FYI: fix broken Caret behavior in JTextAreas with lineWrap=true

2006-03-31 Thread Robert Schuster
Hi,
this patch fixes PR 26842[0]. The fix to GapContent made another drawing problem
visible which occured because document listeners have been registered twice. I
prevented that by not indicating that the document has changed when someone
changes the lineWrap or wrapStyleWord property and only update the view.

The ChangeLog:

2006-03-31  Robert Schuster  [EMAIL PROTECTED]

* javax/swing/text/GapContent.java:
(replace): Move all Position instances from gap's end to
it's start before increasing the gap start.
* javax/swing/plaf/basic/BasicTextAreaUI.java:
(propertyChanged): Update the view only instead of
indicating a document change.

[0] - http://gcc.gnu.org/bugzilla/show_bug.cgi?id=26842

Index: javax/swing/plaf/basic/BasicTextAreaUI.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/plaf/basic/BasicTextAreaUI.java,v
retrieving revision 1.6
diff -u -r1.6 BasicTextAreaUI.java
--- javax/swing/plaf/basic/BasicTextAreaUI.java	31 Oct 2005 21:29:52 -	1.6
+++ javax/swing/plaf/basic/BasicTextAreaUI.java	31 Mar 2006 15:17:58 -
@@ -45,9 +45,11 @@
 import javax.swing.JTextArea;
 import javax.swing.UIDefaults;
 import javax.swing.plaf.ComponentUI;
+import javax.swing.text.Document;
 import javax.swing.text.Element;
 import javax.swing.text.PlainView;
 import javax.swing.text.View;
+import javax.swing.text.ViewFactory;
 import javax.swing.text.WrappedPlainView;
 
 public class BasicTextAreaUI extends BasicTextUI
@@ -108,6 +110,9 @@
 JTextArea comp = (JTextArea)getComponent();
 if (ev.getPropertyName() == lineWrap
 || ev.getPropertyName() == wrapStyleWord)
-  modelChanged();
+  {
+// Changes the View (without modifying the document or it's listeners).
+setView(create(textComponent.getDocument().getDefaultRootElement()));
+  }
   }
 }



signature.asc
Description: PGP signature


signature.asc
Description: OpenPGP digital signature


[cp-patches] Patch: GtkCanvasPeer fix

2006-03-31 Thread Lillian Angel
This fixes a segmentation fault in but #26924. Apparently, the Canvas's
graphics were being used when it was not realized.

2006-03-31  Lillian Angel  [EMAIL PROTECTED]

PR classpath/26924
* gnu/java/awt/peer/gtk/GtkCanvasPeer.java
(realize): New native function.
* include/gnu_java_awt_peer_gtk_GtkCanvasPeer.h:
Added new function declaration.
* native/jni/gtk-peer/gnu_java_awt_peer_gtk_GtkCanvasPeer.c
(realize): New function.

Index: gnu/java/awt/peer/gtk/GtkCanvasPeer.java
===
RCS file: /sources/classpath/classpath/gnu/java/awt/peer/gtk/GtkCanvasPeer.java,v
retrieving revision 1.16
diff -u -r1.16 GtkCanvasPeer.java
--- gnu/java/awt/peer/gtk/GtkCanvasPeer.java	16 Mar 2006 03:24:18 -	1.16
+++ gnu/java/awt/peer/gtk/GtkCanvasPeer.java	31 Mar 2006 18:54:05 -
@@ -38,16 +38,14 @@
 
 package gnu.java.awt.peer.gtk;
 
-import java.awt.AWTEvent;
 import java.awt.Canvas;
 import java.awt.Dimension;
-import java.awt.Graphics;
-import java.awt.event.PaintEvent;
 import java.awt.peer.CanvasPeer;
 
 public class GtkCanvasPeer extends GtkComponentPeer implements CanvasPeer
 {
   native void create ();
+  native void realize ();
 
   public GtkCanvasPeer (Canvas c)
   {
Index: include/gnu_java_awt_peer_gtk_GtkCanvasPeer.h
===
RCS file: /sources/classpath/classpath/include/gnu_java_awt_peer_gtk_GtkCanvasPeer.h,v
retrieving revision 1.3
diff -u -r1.3 gnu_java_awt_peer_gtk_GtkCanvasPeer.h
--- include/gnu_java_awt_peer_gtk_GtkCanvasPeer.h	28 May 2004 17:27:52 -	1.3
+++ include/gnu_java_awt_peer_gtk_GtkCanvasPeer.h	31 Mar 2006 18:54:06 -
@@ -11,6 +11,7 @@
 #endif
 
 JNIEXPORT void JNICALL Java_gnu_java_awt_peer_gtk_GtkCanvasPeer_create (JNIEnv *env, jobject);
+JNIEXPORT void JNICALL Java_gnu_java_awt_peer_gtk_GtkCanvasPeer_realize (JNIEnv *env, jobject);
 
 #ifdef __cplusplus
 }
Index: native/jni/gtk-peer/gnu_java_awt_peer_gtk_GtkCanvasPeer.c
===
RCS file: /sources/classpath/classpath/native/jni/gtk-peer/gnu_java_awt_peer_gtk_GtkCanvasPeer.c,v
retrieving revision 1.11
diff -u -r1.11 gnu_java_awt_peer_gtk_GtkCanvasPeer.c
--- native/jni/gtk-peer/gnu_java_awt_peer_gtk_GtkCanvasPeer.c	22 Sep 2005 20:25:39 -	1.11
+++ native/jni/gtk-peer/gnu_java_awt_peer_gtk_GtkCanvasPeer.c	31 Mar 2006 18:54:06 -
@@ -56,3 +56,17 @@
 
   gdk_threads_leave ();
 }
+
+JNIEXPORT void JNICALL 
+Java_gnu_java_awt_peer_gtk_GtkCanvasPeer_realize (JNIEnv *env, jobject obj)
+{
+  void *ptr;
+
+  gdk_threads_enter ();
+
+  ptr = NSA_GET_PTR (env, obj);
+
+  gtk_widget_realize (GTK_WIDGET (ptr));
+
+  gdk_threads_leave ();
+}


[cp-patches] FYI:JTable.columnSelectionChanged fix

2006-03-31 Thread Audrius Meskauskas

2006-03-31  Audrius Meskauskas  [EMAIL PROTECTED]

   * javax/swing/JTable.java (columnSelectionChanged):
   Treat second repaint parameter as width.
Index: JTable.java
===
RCS file: /sources/classpath/classpath/javax/swing/JTable.java,v
retrieving revision 1.92
diff -u -r1.92 JTable.java
--- JTable.java	31 Mar 2006 10:13:15 -	1.92
+++ JTable.java	31 Mar 2006 21:05:45 -
@@ -1886,6 +1886,7 @@
 
 int idx0 = event.getFirstIndex();
 int idxn = event.getLastIndex();
+System.out.println(IDX +idx0+-+idxn);
 int i;
 
 for (i = 0; i  idx0; i++)
@@ -1896,7 +1897,7 @@
 for (i = idx0; i = idxn; i++)
   xn += columnModel.getColumn(i).getWidth();
 
-repaint(x0, 0, xn, getHeight());
+repaint(x0, 0, xn-x0, getHeight());
   }
  
   /**


Re: [cp-patches] FYI:JTable.columnSelectionChanged fix

2006-03-31 Thread Carsten Neumann


Hi Audrius,

Audrius Meskauskas wrote:

2006-03-31  Audrius Meskauskas  [EMAIL PROTECTED]

   * javax/swing/JTable.java (columnSelectionChanged):
   Treat second repaint parameter as width.




Index: JTable.java
===
RCS file: /sources/classpath/classpath/javax/swing/JTable.java,v
retrieving revision 1.92
diff -u -r1.92 JTable.java
--- JTable.java 31 Mar 2006 10:13:15 -  1.92
+++ JTable.java 31 Mar 2006 21:05:45 -
@@ -1886,6 +1886,7 @@
 
 int idx0 = event.getFirstIndex();

 int idxn = event.getLastIndex();
+System.out.println(IDX +idx0+-+idxn);

   ^^^
looks like this debug code sneaked its way in ;)


 int i;
 
 for (i = 0; i  idx0; i++)

@@ -1896,7 +1897,7 @@
 for (i = idx0; i = idxn; i++)
   xn += columnModel.getColumn(i).getWidth();
 
-repaint(x0, 0, xn, getHeight());

+repaint(x0, 0, xn-x0, getHeight());
   }
  
   /**


Thanks,
Carsten



[cp-patches] Patch: Component fix

2006-03-31 Thread Lillian Angel
I am in the process of writing a mauve test for this.
When we translate from new events to old events, if a character on the
keyboard is pressed the key value should be set to the value of the
character.

2006-03-31  Lillian Angel  [EMAIL PROTECTED]

* java/awt/Component.java
(translateEvent): oldKey should be the value of the
key char.

Index: java/awt/Component.java
===
RCS file: /sources/classpath/classpath/java/awt/Component.java,v
retrieving revision 1.109
diff -u -r1.109 Component.java
--- java/awt/Component.java	23 Mar 2006 23:22:39 -	1.109
+++ java/awt/Component.java	31 Mar 2006 21:39:22 -
@@ -4875,7 +4875,7 @@
 oldKey = Event.UP;
 break;
   default:
-oldKey = newKey;
+oldKey = (int) ((KeyEvent) e).getKeyChar();
   }
 
 translated = new Event (target, when, oldID,


[cp-patches] FYI:JTable repaint fixes when selecting multiple rows with arrow keys

2006-03-31 Thread Audrius Meskauskas
Trying to select the multiple rows with arrow keys indicates that the 
DefaultListSelectionModel is not firing correct events to repaint the 
changed area. This path fixes that problem.


2006-03-31  Audrius Meskauskas  [EMAIL PROTECTED]

   * javax/swing/JTable.java (columnSelectionChanged):
   Removed print statement.
   * javax/swing/DefaultListSelectionModel.java
   (addSelectionInterval, removeSelectionInterval):
   Fire the difference between selection. (setLeadSelectionIndex):
   Fire the difference and mark current and previous lead
   selection indexes for repaint.

Index: DefaultListSelectionModel.java
===
RCS file: /sources/classpath/classpath/javax/swing/DefaultListSelectionModel.java,v
retrieving revision 1.27
diff -u -r1.27 DefaultListSelectionModel.java
--- DefaultListSelectionModel.java	31 Mar 2006 10:13:15 -	1.27
+++ DefaultListSelectionModel.java	31 Mar 2006 21:39:21 -
@@ -286,8 +286,14 @@
 int beg = sel.nextSetBit(0), end = -1;
 for(int i=beg; i = 0; i=sel.nextSetBit(i+1)) 
   end = i;
-if (sel.equals(oldSel) == false)
-  fireValueChanged(beg, end, valueIsAdjusting);
+
+BitSet old = (BitSet) oldSel;
+
+// The new and previous lead location requires repainting.
+old.set(oldLeadIndex, !sel.get(oldLeadIndex));
+old.set(leadSelectionIndex, !sel.get(leadSelectionIndex));
+
+fireDifference(sel, old);
   }
 
   /**
@@ -492,8 +498,7 @@
 leadSelectionIndex = index1;
 anchorSelectionIndex = index0;
 sel.set(lo, hi+1);
-if (sel.equals(oldSel) == false)
-  fireValueChanged(lo, hi, valueIsAdjusting);
+fireDifference(sel, (BitSet) oldSel);
   }
   }
 
@@ -530,8 +535,8 @@
 //TODO: will probably need MouseDragged to test properly and know if this works
 setAnchorSelectionIndex(index0);
 leadSelectionIndex = index1;
-if (sel.equals(oldSel) == false)
-  fireValueChanged(lo, hi, valueIsAdjusting);
+
+fireDifference(sel, (BitSet) oldSel);
   }
 
   /**
Index: JTable.java
===
RCS file: /sources/classpath/classpath/javax/swing/JTable.java,v
retrieving revision 1.93
diff -u -r1.93 JTable.java
--- JTable.java	31 Mar 2006 21:10:08 -	1.93
+++ JTable.java	31 Mar 2006 21:39:29 -
@@ -1886,7 +1886,6 @@
 
 int idx0 = event.getFirstIndex();
 int idxn = event.getLastIndex();
-System.out.println(IDX +idx0+-+idxn);
 int i;
 
 for (i = 0; i  idx0; i++)
Index: plaf/basic/BasicTableUI.java
===
RCS file: /sources/classpath/classpath/javax/swing/plaf/basic/BasicTableUI.java,v
retrieving revision 1.48
diff -u -r1.48 BasicTableUI.java
--- plaf/basic/BasicTableUI.java	31 Mar 2006 10:13:16 -	1.48
+++ plaf/basic/BasicTableUI.java	31 Mar 2006 21:39:34 -
@@ -1250,6 +1250,8 @@
 widths[i] = cmodel.getColumn(i).getWidth();
   }
 
+System.out.println(r0+:+c0+-+rn+:+cn);
+
 Rectangle bounds = table.getCellRect(r0, c0, false);
 bounds.height = table.getRowHeight()+table.getRowMargin();
 


Re: [cp-patches] Patch: FYI: JPEGQTable

2006-03-31 Thread Thomas Fitzsimmons
On Thu, 2006-03-30 at 19:49 -0700, Tom Tromey wrote:
  Tom == Thomas Fitzsimmons [EMAIL PROTECTED] writes:
 
 Tom +  public static final JPEGQTable K1Luminance = new JPEGQTable(new int[]
 Tom +  {
 
 For these it would be mildly better to have a private constructor
 which doesn't copy the argument.
 
 Tom +int[] tableCopy = new int[table.length];
 Tom +System.arraycopy(table, 0, tableCopy, 0, table.length);
 Tom +return tableCopy;
 
 This is:  return (int[]) table.clone();
 
 Tom +  public JPEGQTable getScaledInstance(float scaleFactor,
 Tom +  boolean forceBaseline)
 Tom +  {
 Tom +int[] scaledTable = getTable();
 
 Somehow this should also be able to make a single copy of the table.
 Right now it makes 2 -- one here and one in the constructor.

Thanks for the comments.  They're all fixed by the attached patch, which
I've committed.

Tom

2006-03-31  Thomas Fitzsimmons  [EMAIL PROTECTED]

* javax/imageio/plugins/jpeg/JPEGHuffmanTable.java: Eliminate
unnecessary copying.
* javax/imageio/plugins/jpeg/JPEGQTable.java: Likewise.

Index: javax/imageio/plugins/jpeg/JPEGHuffmanTable.java
===
RCS file: /sources/classpath/classpath/javax/imageio/plugins/jpeg/JPEGHuffmanTable.java,v
retrieving revision 1.2
diff -u -r1.2 JPEGHuffmanTable.java
--- javax/imageio/plugins/jpeg/JPEGHuffmanTable.java	31 Mar 2006 02:07:31 -	1.2
+++ javax/imageio/plugins/jpeg/JPEGHuffmanTable.java	31 Mar 2006 21:50:01 -
@@ -55,6 +55,8 @@
*/
   private short[] values;
 
+  // The private constructors are used for these final fields to avoid
+  // unnecessary copying.
   /**
* The standard JPEG AC chrominance Huffman table.
*/
@@ -93,7 +95,7 @@
   0xe3, 0xe4, 0xe5, 0xe6, 0xe7,
   0xe8, 0xe9, 0xea, 0xf2, 0xf3,
   0xf4, 0xf5, 0xf6, 0xf7, 0xf8,
-  0xf9, 0xfa });
+  0xf9, 0xfa }, false);
 
   /**
* The standard JPEG AC luminance Huffman table.
@@ -133,7 +135,7 @@
  0xe4, 0xe5, 0xe6, 0xe7, 0xe8,
  0xe9, 0xea, 0xf1, 0xf2, 0xf3,
  0xf4, 0xf5, 0xf6, 0xf7, 0xf8,
- 0xf9, 0xfa });
+ 0xf9, 0xfa }, false);
 
   /**
* The standard JPEG DC chrominance Huffman table.
@@ -142,7 +144,7 @@
   new JPEGHuffmanTable(new short[] { 0, 3, 1, 1, 1, 1, 1, 1, 1, 1,
  1, 0, 0, 0, 0, 0 },
new short[] { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9,
- 10, 11 });
+ 10, 11 }, false);
 
   /**
* The standard JPEG DC luminance Huffman table.
@@ -151,7 +153,7 @@
   new JPEGHuffmanTable(new short[] { 0, 1, 5, 1, 1, 1, 1, 1, 1, 0,
  0, 0, 0, 0, 0, 0 },
new short[] { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9,
- 10, 11 });
+ 10, 11 }, false);
 
   /**
* Construct and initialize a Huffman table. Copies are created of
@@ -168,9 +170,28 @@
*/
   public JPEGHuffmanTable(short[] lengths, short[] values)
   {
-if (lengths == null || values == null || lengths.length  16
-|| values.length  256)
-  throw new IllegalArgumentException(invalid length or values array);
+// Create copies of the lengths and values arguments.
+this(checkLengths(lengths), checkValues(values, lengths), true);
+  }
+
+  /**
+   * Private constructor that avoids unnecessary copying and argument
+   * checking.
+   *
+   * @param lengths an array of Huffman code lengths
+   * @param values a sorted array of Huffman values
+   * @param copy true if copies should be created of the given arrays
+   */
+  private JPEGHuffmanTable(short[] lengths, short[] values, boolean copy)
+  {
+this.lengths = copy ? (short[]) lengths.clone() : lengths;
+this.values = copy ? (short[]) values.clone() : values;
+  }
+
+  private static short[] checkLengths(short[] lengths)
+  {
+if (lengths == null || lengths.length  16)
+  throw new IllegalArgumentException(invalid length array);
 
 for (int i = 0; i  lengths.length; i++)
   {
@@ -178,12 +199,6 @@
   throw new IllegalArgumentException(negative length);
   }
 
-for (int i = 0; i  values.length; i++)
-  {
-if (values[i]  0)
-  throw new IllegalArgumentException(negative value);
-  }
-
 int sum = 0;
 for (int i = 0; i  lengths.length; i++)
   {
@@ -192,15 +207,30 @@
  +  for code length  + (i + 1));

Re: [cp-patches] FYI:JTable repaint fixes when selecting multiple rows with arrow keys:Fixed mistake in the patch.

2006-03-31 Thread Audrius Meskauskas
The previous patch includes unplanned change (adding debug code) to the 
BasicTableUI. The corrected patch is attached. The change was not 
comitted to CVS repository, only posted to the list. Sorry.


2006-03-31  Audrius Meskauskas  [EMAIL PROTECTED]

   * javax/swing/JTable.java (columnSelectionChanged):
   Removed print statement.
   * javax/swing/DefaultListSelectionModel.java
   (addSelectionInterval, removeSelectionInterval):
   Fire the difference between selection. (setLeadSelectionIndex):
   Fire the difference and mark current and previous lead
   selection indexes for repaint.


Index: DefaultListSelectionModel.java
===
RCS file: /sources/classpath/classpath/javax/swing/DefaultListSelectionModel.java,v
retrieving revision 1.27
diff -u -r1.27 DefaultListSelectionModel.java
--- DefaultListSelectionModel.java	31 Mar 2006 10:13:15 -	1.27
+++ DefaultListSelectionModel.java	31 Mar 2006 21:39:21 -
@@ -286,8 +286,14 @@
 int beg = sel.nextSetBit(0), end = -1;
 for(int i=beg; i = 0; i=sel.nextSetBit(i+1)) 
   end = i;
-if (sel.equals(oldSel) == false)
-  fireValueChanged(beg, end, valueIsAdjusting);
+
+BitSet old = (BitSet) oldSel;
+
+// The new and previous lead location requires repainting.
+old.set(oldLeadIndex, !sel.get(oldLeadIndex));
+old.set(leadSelectionIndex, !sel.get(leadSelectionIndex));
+
+fireDifference(sel, old);
   }
 
   /**
@@ -492,8 +498,7 @@
 leadSelectionIndex = index1;
 anchorSelectionIndex = index0;
 sel.set(lo, hi+1);
-if (sel.equals(oldSel) == false)
-  fireValueChanged(lo, hi, valueIsAdjusting);
+fireDifference(sel, (BitSet) oldSel);
   }
   }
 
@@ -530,8 +535,8 @@
 //TODO: will probably need MouseDragged to test properly and know if this works
 setAnchorSelectionIndex(index0);
 leadSelectionIndex = index1;
-if (sel.equals(oldSel) == false)
-  fireValueChanged(lo, hi, valueIsAdjusting);
+
+fireDifference(sel, (BitSet) oldSel);
   }
 
   /**
Index: JTable.java
===
RCS file: /sources/classpath/classpath/javax/swing/JTable.java,v
retrieving revision 1.93
diff -u -r1.93 JTable.java
--- JTable.java	31 Mar 2006 21:10:08 -	1.93
+++ JTable.java	31 Mar 2006 21:39:29 -
@@ -1886,7 +1886,6 @@
 
 int idx0 = event.getFirstIndex();
 int idxn = event.getLastIndex();
-System.out.println(IDX +idx0+-+idxn);
 int i;
 
 for (i = 0; i  idx0; i++)


[cp-patches] Patch: FYI: speed up split-for-gcj

2006-03-31 Thread Tom Tromey
I'm checking this in.

This hugely speeds up the split-for-gcj script.  On my machine it goes
from more than two minutes to about 6 seconds.  (We could probably do
even better but this script should be very portable...)

This also fixes a bug.  I noticed that source files could be
classified into more than one .list file, eg a gnu/java/beans file
would end up in both the gnu-java-beans and java-beans lists.  This
meant that such files were compiled more than once.

gcj folks, I will check this in to svn trunk soon, and probably the
4.1 branch for good measure.

Tom

Index: ChangeLog
from  Tom Tromey  [EMAIL PROTECTED]

* lib/split-for-gcj.sh: Updated for multi-field format.
* lib/Makefile.am (CLEANFILES): Added classes.2.
* lib/gen-classlist.sh.in (GCJ): Removed.  Create classes.1 and
classes.2 using multiple fields.

Index: lib/Makefile.am
===
RCS file: /cvsroot/classpath/classpath/lib/Makefile.am,v
retrieving revision 1.113
diff -u -r1.113 Makefile.am
--- lib/Makefile.am 24 Mar 2006 17:04:21 - 1.113
+++ lib/Makefile.am 31 Mar 2006 22:21:58 -
@@ -155,7 +155,7 @@
 
 EXTRA_DIST = standard.omit mkcollections.pl.in Makefile.gcj split-for-gcj.sh
 CLEANFILES = compile-classes resources classes \
-   glibj.zip classes.1 \
+   glibj.zip classes.1 classes.2 \
$(top_builddir)/gnu/java/locale/LocaleData.java \
$(JAVA_DEPEND)
 
Index: lib/gen-classlist.sh.in
===
RCS file: /cvsroot/classpath/classpath/lib/gen-classlist.sh.in,v
retrieving revision 1.33
diff -u -r1.33 gen-classlist.sh.in
--- lib/gen-classlist.sh.in 13 Feb 2006 19:13:16 - 1.33
+++ lib/gen-classlist.sh.in 31 Mar 2006 22:21:58 -
@@ -7,16 +7,34 @@
 LC_ALL=C; export LC_ALL
 LANG=C; export LANG
 
-# We use this to decide whether we need to invoke the split script.
-GCJ=@GCJ@
-
 echo Adding java source files from srcdir '@top_srcdir@'.
[EMAIL PROTECTED]@ @top_srcdir@/java @top_srcdir@/javax @top_srcdir@/gnu \
-   @top_srcdir@/org \
-   @top_srcdir@/external/w3c_dom @top_srcdir@/external/sax \
-   @top_srcdir@/external/relaxngDatatype \
-   -follow -type f -print | sort -r | grep '\.java$' \
-${top_builddir}/lib/classes.1
+# We construct 'classes.1' as a series of lines.  Each line
+# has three fields, which are separated by spaces.  The first
+# field is the package of this class (separated by /s).
+# The second field is the name of the top-level directory for
+# this file, relative to the build directory.  E.g., it might
+# look like ../../classpath/vm/reference.
+# The third field is the file name, like java/lang/Object.java.
+# We do this because it makes splitting for the gcj build much
+# cheaper.
+(cd @top_srcdir@
+ @FIND@ java javax gnu org -follow -name '*.java' -print |
+ sort -r | sed -e 's,/\([^/]*\)$, \1,' |
+ while read pkg file; do
+echo $pkg @top_srcdir@ $pkg/$file
+ done)  ${top_builddir}/lib/classes.1
+
+# The same, but for the external code.
+# Right now all external code is in org/.
+for dir in @top_srcdir@/external/w3c_dom \
+   @top_srcdir@/external/sax @top_srcdir@/external/relaxngDatatype; do
+  (cd $dir
+  @FIND@ org -follow -name '*.java' -print |
+  sort -r | sed -e 's,/\([^/]*\)$, \1,' |
+  while read pkg file; do
+ echo $pkg $dir $pkg/$file
+  done)
+done  ${top_builddir}/lib/classes.1
 
 # Generate files for the VM classes.
 :  vm.omit
@@ -29,18 +47,19 @@
   if test -d $subdir; then
 @FIND@ $subdir -name '*.java' -print
   fi
-   done) |
-   while read f; do
-  echo $dir/$f  vm.add
-  echo $f  vm.omit
+   done) | sed -e 's,/\([^/]*\)$, \1,' |
+   while read pkg file; do
+  echo $pkg $dir $pkg/$file  vm.add
+  echo $pkg/$file  vm.omit
done
 done
 
 # Only include generated files once.
 if test ! ${top_builddir} -ef @top_srcdir@; then
   echo Adding generated files in builddir '${top_builddir}'.
-  @FIND@ ${top_builddir}/gnu ${top_builddir}/java -follow -type f -print \
-  | sort | grep '\.java$'  ${top_builddir}/lib/classes.1
+  # Currently the only generated files are in gnu.*.
+  @FIND@ ${top_builddir}/gnu -follow -name '*.java' -print \
+  | sort  ${top_builddir}/lib/classes.1
 fi
 
 
@@ -51,6 +70,7 @@
fi
 done
 
+# FIXME: could be more efficient by constructing a series of greps.
 for filexp in `cat tmp.omit`; do
grep -v ${filexp}  ${top_builddir}/lib/classes.1  
${top_builddir}/lib/classes.2
mv ${top_builddir}/lib/classes.2 ${top_builddir}/lib/classes.1
@@ -72,18 +92,20 @@
 rm tmp.omit
 
 new=
-if test -e ${top_builddir}/lib/classes; then
-  p=`diff ${top_builddir}/lib/classes ${top_builddir}/lib/classes.1`
+if test -e ${top_builddir}/lib/classes.2; then
+  p=`diff ${top_builddir}/lib/classes.2 ${top_builddir}/lib/classes.1`
   if test $p != ; then
 new=true
-cp ${top_builddir}/lib/classes.1 ${top_builddir}/lib/classes
   fi
 else
   new=true
- 

[cp-testresults] Japi diffs for classpath

2006-03-31 Thread Stuart Ballard
Japi diff jdk14 vs classpath:
Full results:
http://www.kaffe.org/~stuart/japi/htmlout/h-jdk14-classpath.html

Changes since last run:

-Comparison run at Thu Mar 30 11:17:32 2006 GMT
-jdk14 API scanned at 2006/03/30 05:20:24 EST
-classpath API scanned at 2006/03/30 06:00:44 EST
+Comparison run at Fri Mar 31 11:01:35 2006 GMT
+jdk14 API scanned at 2006/03/31 05:16:00 EST
+classpath API scanned at 2006/03/31 05:48:34 EST
-javax.imageio.plugins.jpeg: 9.45% good, 90.54% missing
+javax.imageio.plugins.jpeg: 18.9% good, 81.09% missing
-Total: 98.58% good, 0.12% minor, 1.2% missing
+Total: 98.6% good, 0.12% minor, 1.18% missing
-Classes: 151 minor, 13 missing.
+Classes: 151 minor, 12 missing.
-class javax.imageio.plugins.jpeg.JPEGQTable: missing in classpath


Japi diff jdk15 vs classpath:
Full results:
http://www.kaffe.org/~stuart/japi/htmlout/h-jdk15-classpath.html

Changes since last run:

-Comparison run at Thu Mar 30 11:20:44 2006 GMT
-jdk15 API scanned at 2006/03/30 05:09:29 EST
-classpath API scanned at 2006/03/30 06:00:44 EST
+Comparison run at Fri Mar 31 11:04:00 2006 GMT
+jdk15 API scanned at 2006/03/31 05:07:12 EST
+classpath API scanned at 2006/03/31 05:48:34 EST
-javax.imageio.plugins.jpeg: 9% good, 91% missing
+javax.imageio.plugins.jpeg: 18.09% good, 81.9% missing
-javax.xml.datatype: 99% good, 0.49% bad, 0.49% missing
+javax.xml.datatype: 99.5% good, 0.49% bad
-javax.xml.validation: 89.06% good, 10.93% missing
+javax.xml.validation: 100% good
-Total: 89.91% good, 0.22% minor, 0.75% bad, 9.09% missing
+Total: 89.94% good, 0.22% minor, 0.75% bad, 9.07% missing
-Classes: 212 minor, 155 bad, 147 missing.
+Classes: 212 minor, 155 bad, 145 missing.
-Methods: 98 minor, 1009 bad, 675 missing.
+Methods: 98 minor, 1009 bad, 674 missing.
-class javax.imageio.plugins.jpeg.JPEGQTable: missing in classpath
-Missing
-method javax.xml.datatype.DatatypeFactory.newDurationDayTime(boolean, 
java.math.BigInteger, java.math.BigInteger, java.math.BigInteger, 
java.math.BigInteger): missing in classpath
-
-javax.xml.validation:
-Missing
-class javax.xml.validation.SchemaFactoryLoader: missing in classpath


Japi diff classpath vs jdk15:
Full results:
http://www.kaffe.org/~stuart/japi/htmlout/h-classpath-jdk15.html

Changes since last run:

-Comparison run at Thu Mar 30 11:23:39 2006 GMT
-classpath API scanned at 2006/03/30 06:00:44 EST
-jdk15 API scanned at 2006/03/30 05:09:29 EST
+Comparison run at Fri Mar 31 11:06:22 2006 GMT
+classpath API scanned at 2006/03/31 05:48:34 EST
+jdk15 API scanned at 2006/03/31 05:07:12 EST
-javax.xml.datatype: 98.08% good, 0.95% bad, 0.95% missing
+javax.xml.datatype: 98.56% good, 0.95% bad, 0.47% missing
-javax.xml.validation: 98.31% good, 1.68% bad
+javax.xml.validation: 98.49% good, 1.5% bad
-Methods: 19 bad, 20 missing, 16 abs.add.
+Methods: 19 bad, 19 missing, 16 abs.add.
-method javax.xml.datatype.DatatypeFactory.newDurationDayTime(boolean, 
java.math.BigInteger, java.math.BigInteger, java.math.BigInteger, 
java.math.BigDecimal): missing in jdk15




___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] FAIL: classpath build with gcj trunk on Fri Mar 31 17:08:10 UTC 2006

2006-03-31 Thread cpdev
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-beans-beancontext.deps -MT 
lists/java-beans-beancontext.stamp -MP @lists/java-beans-beancontext.list
echo timestamp  lists/java-beans-beancontext.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-beans-decoder.deps -MT 
lists/java-beans-decoder.stamp -MP @lists/java-beans-decoder.list
echo timestamp  lists/java-beans-decoder.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-beans-editors.deps -MT 
lists/java-beans-editors.stamp -MP @lists/java-beans-editors.list
echo timestamp  lists/java-beans-editors.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-beans-encoder.deps -MT 
lists/java-beans-encoder.stamp -MP @lists/java-beans-encoder.list
echo timestamp  lists/java-beans-encoder.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-beans.deps -MT lists/java-beans.stamp -MP 
@lists/java-beans.list
echo timestamp  lists/java-beans.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-io.deps -MT lists/java-io.stamp -MP 
@lists/java-io.list
echo timestamp  lists/java-io.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-lang-annotation.deps -MT 
lists/java-lang-annotation.stamp -MP @lists/java-lang-annotation.list
echo timestamp  lists/java-lang-annotation.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-lang-ref.deps -MT lists/java-lang-ref.stamp -MP 
@lists/java-lang-ref.list
echo timestamp  lists/java-lang-ref.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-lang-reflect.deps -MT lists/java-lang-reflect.stamp 
-MP @lists/java-lang-reflect.list
echo timestamp  lists/java-lang-reflect.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-lang.deps -MT lists/java-lang.stamp -MP 
@lists/java-lang.list
../../classpath/java/lang/Class.java: In class 'java.lang.Class':
../../classpath/java/lang/Class.java: In constructor 
'(java.lang.Object,java.security.ProtectionDomain)':
../../classpath/java/lang/Class.java:141: internal compiler error: Segmentation 
fault
Please submit a full bug report,
with preprocessed source if appropriate.
See URL:http://gcc.gnu.org/bugs.html for instructions.
make[2]: *** [lists/java-lang.stamp] Error 1
make[2]: Leaving directory `/home/cpdev/Nightly/classpath/build/lib'
make[1]: *** [compile-classes] Error 2
make[1]: Leaving directory `/home/cpdev/Nightly/classpath/build/lib'
make: *** [all-recursive] Error 1


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] FAIL: classpath build with jikes on Fri Mar 31 17:14:09 UTC 2006

2006-03-31 Thread cpdev

   120. public void EditorContainer()
   ^--^
*** Semantic Warning: The name of this method EditorContainer matches the 
name of the containing class. However, the method is not a constructor since 
its declarator is qualified with a type.

Issued 2 semantic warnings compiling 
../../classpath/javax/swing/plaf/metal/MetalSliderUI.java:

   129.   protected final int TICK_BUFFER = 4;
  ^-^
*** Semantic Warning: Final field TICK_BUFFER is initialized with a constant 
expression and could be made static to save space.


   132.   protected final String SLIDER_FILL = JSlider.isFilled;
 ^--^
*** Semantic Warning: Final field SLIDER_FILL is initialized with a constant 
expression and could be made static to save space.

Issued 1 semantic warning compiling 
../../classpath/javax/swing/plaf/basic/BasicInternalFrameUI.java:

   175. protected final int RESIZE_NONE = 0;
^-^
*** Semantic Warning: Final field RESIZE_NONE is initialized with a constant 
expression and could be made static to save space.

Issued 1 lexical warning in 
../../classpath/gnu/java/rmi/registry/RegistryImpl_Stub.java:

61. private static java.lang.reflect.Method $method_bind_0;
^^
*** Lexical Warning: The use of $ in an identifier, while legal, is strongly 
discouraged, since it can conflict with compiler-generated names. If you are 
trying to access a nested type, use . instead of $.
make[1]: *** [compile-classes] Error 1
make[1]: Leaving directory `/home/cpdev/Nightly/classpath/jikes-build/lib'
make: *** [all-recursive] Error 1


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] FAIL: regressions for libgcj on Fri Mar 31 18:01:12 UTC 2006

2006-03-31 Thread cpdev
Baseline from: Thu Mar 30 19:01:15 UTC 2006

Regressions:
FAIL: Thread_Sleep -O3 output - bytecode-native test

Improvements:
XPASS: PR26858 -O3 output - bytecode-native test
XPASS: PR26858 -O3 output - source compiled test
XPASS: PR26858 output - bytecode-native test
XPASS: PR26858 output - source compiled test

New fails:

Totals:
PASS: 3432
XPASS: 8
FAIL: 1
XFAIL: 11


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] FAIL: classpath build with jikes on Fri Mar 31 22:33:08 UTC 2006

2006-03-31 Thread cpdev

   120. public void EditorContainer()
   ^--^
*** Semantic Warning: The name of this method EditorContainer matches the 
name of the containing class. However, the method is not a constructor since 
its declarator is qualified with a type.

Issued 2 semantic warnings compiling 
../../classpath/javax/swing/plaf/metal/MetalSliderUI.java:

   129.   protected final int TICK_BUFFER = 4;
  ^-^
*** Semantic Warning: Final field TICK_BUFFER is initialized with a constant 
expression and could be made static to save space.


   132.   protected final String SLIDER_FILL = JSlider.isFilled;
 ^--^
*** Semantic Warning: Final field SLIDER_FILL is initialized with a constant 
expression and could be made static to save space.

Issued 1 semantic warning compiling 
../../classpath/javax/swing/plaf/basic/BasicInternalFrameUI.java:

   175. protected final int RESIZE_NONE = 0;
^-^
*** Semantic Warning: Final field RESIZE_NONE is initialized with a constant 
expression and could be made static to save space.

Issued 1 lexical warning in 
../../classpath/gnu/java/rmi/registry/RegistryImpl_Stub.java:

61. private static java.lang.reflect.Method $method_bind_0;
^^
*** Lexical Warning: The use of $ in an identifier, while legal, is strongly 
discouraged, since it can conflict with compiler-generated names. If you are 
trying to access a nested type, use . instead of $.
make[1]: *** [compile-classes] Error 1
make[1]: Leaving directory `/home/cpdev/Nightly/classpath/jikes-build/lib'
make: *** [all-recursive] Error 1


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] FAIL: regressions for mauve-jamvm on Sat Apr 1 00:07:42 UTC 2006

2006-03-31 Thread cpdev
Baseline from: Fri Mar 31 18:47:06 UTC 2006

Regressions:
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure4:
 ElementBuffer insertUpdate: third insertion (number 3)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure4:
 final structure (number 2)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure4:
 final structure (number 3)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure4:
 final structure (number 4)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure5:
 ElementBuffer insertUpdate: second insertion (number 19)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure5:
 ElementBuffer insertUpdate: second insertion (number 22)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure5:
 ElementBuffer insertUpdate: second insertion (number 29)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure5:
 ElementBuffer insertUpdate: second insertion (number 30)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure5:
 ElementBuffer insertUpdate: second insertion (number 31)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 19)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 23)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 26)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 29)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 33)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 34)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 35)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 31)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 34)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 41)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 42)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 43)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 44)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 45)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument1:
 second doc event (number 8)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument2:
 second doc event (number 4)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create fifth leaf element (number 1)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create fifth leaf element (number 2)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create fifth leaf element (number 5)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create fourth leaf element (number 1)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create fourth leaf element (number 2)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create fourth leaf element (number 4)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create sixth leaf element (number 1)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create sixth leaf element (number 2)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create sixth leaf element (number 5)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create sixth leaf element (number 6)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create 

[cp-testresults] FAIL: classpath build with gcj trunk on Sat Apr 1 03:36:37 UTC 2006

2006-03-31 Thread cpdev
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-awt-peer.deps -MT lists/java-awt-peer.stamp -MP 
@lists/java-awt-peer.list
echo timestamp  lists/java-awt-peer.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-awt-print.deps -MT lists/java-awt-print.stamp -MP 
@lists/java-awt-print.list
echo timestamp  lists/java-awt-print.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-awt.deps -MT lists/java-awt.stamp -MP 
@lists/java-awt.list
echo timestamp  lists/java-awt.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-beans-beancontext.deps -MT 
lists/java-beans-beancontext.stamp -MP @lists/java-beans-beancontext.list
echo timestamp  lists/java-beans-beancontext.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-beans.deps -MT lists/java-beans.stamp -MP 
@lists/java-beans.list
echo timestamp  lists/java-beans.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-io.deps -MT lists/java-io.stamp -MP 
@lists/java-io.list
echo timestamp  lists/java-io.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-lang-annotation.deps -MT 
lists/java-lang-annotation.stamp -MP @lists/java-lang-annotation.list
echo timestamp  lists/java-lang-annotation.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-lang-ref.deps -MT lists/java-lang-ref.stamp -MP 
@lists/java-lang-ref.list
echo timestamp  lists/java-lang-ref.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-lang-reflect.deps -MT lists/java-lang-reflect.stamp 
-MP @lists/java-lang-reflect.list
echo timestamp  lists/java-lang-reflect.stamp
/home/cpdev/Nightly/gcc/install/bin/gcj -Wno-deprecated --encoding=UTF-8 
--bootclasspath '' --classpath 
..:../../classpath/vm/reference:../../classpath:../../classpath/external/w3c_dom:../../classpath/external/sax:../../classpath/external/relaxngDatatype:.:
 -C -d . -MD -MF lists/java-lang.deps -MT lists/java-lang.stamp -MP 
@lists/java-lang.list
../../classpath/java/lang/Class.java: In class 'java.lang.Class':
../../classpath/java/lang/Class.java: In constructor 
'(java.lang.Object,java.security.ProtectionDomain)':
../../classpath/java/lang/Class.java:141: internal compiler error: Segmentation 
fault
Please submit a full bug report,
with preprocessed source if appropriate.
See URL:http://gcc.gnu.org/bugs.html for instructions.
make[2]: *** [lists/java-lang.stamp] Error 1
make[2]: Leaving directory `/home/cpdev/Nightly/classpath/build/lib'
make[1]: *** [compile-classes] Error 2
make[1]: Leaving directory `/home/cpdev/Nightly/classpath/build/lib'
make: *** [all-recursive] Error 1


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] FAIL: classpath build with jikes on Sat Apr 1 03:49:13 UTC 2006

2006-03-31 Thread cpdev

   120. public void EditorContainer()
   ^--^
*** Semantic Warning: The name of this method EditorContainer matches the 
name of the containing class. However, the method is not a constructor since 
its declarator is qualified with a type.

Issued 2 semantic warnings compiling 
../../classpath/javax/swing/plaf/metal/MetalSliderUI.java:

   129.   protected final int TICK_BUFFER = 4;
  ^-^
*** Semantic Warning: Final field TICK_BUFFER is initialized with a constant 
expression and could be made static to save space.


   132.   protected final String SLIDER_FILL = JSlider.isFilled;
 ^--^
*** Semantic Warning: Final field SLIDER_FILL is initialized with a constant 
expression and could be made static to save space.

Issued 1 semantic warning compiling 
../../classpath/javax/swing/plaf/basic/BasicInternalFrameUI.java:

   175. protected final int RESIZE_NONE = 0;
^-^
*** Semantic Warning: Final field RESIZE_NONE is initialized with a constant 
expression and could be made static to save space.

Issued 1 lexical warning in 
../../classpath/gnu/java/rmi/registry/RegistryImpl_Stub.java:

61. private static java.lang.reflect.Method $method_bind_0;
^^
*** Lexical Warning: The use of $ in an identifier, while legal, is strongly 
discouraged, since it can conflict with compiler-generated names. If you are 
trying to access a nested type, use . instead of $.
make[1]: *** [compile-classes] Error 1
make[1]: Leaving directory `/home/cpdev/Nightly/classpath/jikes-build/lib'
make: *** [all-recursive] Error 1


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] classpath daily snapshot 20060401 FAILED

2006-03-31 Thread Michael Koch
   ^-^
*** Semantic Caution: The shift count -15 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.


   299. aa = aa  3 | aa  -3;
  ^^
*** Semantic Caution: The shift count -3 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.


   301. dd = dd  9 | dd  -9;
  ^^
*** Semantic Caution: The shift count -9 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.


   303. cc = cc  11 | cc  -11;
   ^-^
*** Semantic Caution: The shift count -11 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.


   305. bb = bb  15 | bb  -15;
   ^-^
*** Semantic Caution: The shift count -15 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.


   307. aa = aa  3 | aa  -3;
  ^^
*** Semantic Caution: The shift count -3 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.


   309. dd = dd  9 | dd  -9;
  ^^
*** Semantic Caution: The shift count -9 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.


   311. cc = cc  11 | cc  -11;
   ^-^
*** Semantic Caution: The shift count -11 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.


   313. bb = bb  15 | bb  -15;
   ^-^
*** Semantic Caution: The shift count -15 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.


   315. aa = aa  3 | aa  -3;
  ^^
*** Semantic Caution: The shift count -3 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.


   317. dd = dd  9 | dd  -9;
  ^^
*** Semantic Caution: The shift count -9 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.


   319. cc = cc  11 | cc  -11;
   ^-^
*** Semantic Caution: The shift count -11 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.


   321. bb = bb  15 | bb  -15;
   ^-^
*** Semantic Caution: The shift count -15 is negative; it will be masked to the 
appropriate width and behave as a positive shift count.

Issued 1 semantic warning compiling 
../../external/sax/org/xml/sax/helpers/ParserAdapter.java:

   564. atts.addAttribute (nsSupport.XMLNS, prefix,
 ^---^
*** Semantic Warning: Accessing the class field XMLNS via an instance is 
discouraged because the field accessed will be the one in the variable's 
declared type, not the instance's dynamic type.

Issued 1 semantic warning compiling 
../../javax/swing/tree/DefaultTreeCellEditor.java:

   120. public void EditorContainer()
   ^--^
*** Semantic Warning: The name of this method EditorContainer matches the 
name of the containing class. However, the method is not a constructor since 
its declarator is qualified with a type.

Issued 2 semantic warnings compiling 
../../javax/swing/plaf/metal/MetalSliderUI.java:

   129.   protected final int TICK_BUFFER = 4;
  ^-^
*** Semantic Warning: Final field TICK_BUFFER is initialized with a constant 
expression and could be made static to save space.


   132.   protected final String SLIDER_FILL = JSlider.isFilled;
 ^--^
*** Semantic Warning: Final field SLIDER_FILL is initialized with a constant 
expression and could be made static to save space.

Issued 1 semantic warning compiling 
../../javax/swing/plaf/basic/BasicInternalFrameUI.java:

   175. protected final int RESIZE_NONE = 0;
^-^
*** Semantic Warning: Final field RESIZE_NONE is initialized with a constant 
expression and could be made static to save space.

Issued 1 lexical warning in 
../../gnu/java/rmi/registry/RegistryImpl_Stub.java:

61. private static java.lang.reflect.Method $method_bind_0;
^^
*** Lexical Warning: The use of $ in an identifier, while legal, is strongly 
discouraged, since it can conflict with compiler-generated names. If you are 
trying to access a nested type, use . instead of $.
make[1]: *** [compile-classes] Error 1
make[1]: Leaving directory `/home/mkoch/src/classpath/build/lib'
make: *** [all-recursive] Error 1



[cp-testresults] FAIL: regressions for mauve-jamvm on Sat Apr 1 05:22:12 UTC 2006

2006-03-31 Thread cpdev
Baseline from: Fri Mar 31 18:47:06 UTC 2006

Regressions:
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure4:
 ElementBuffer insertUpdate: third insertion (number 3)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure4:
 final structure (number 2)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure4:
 final structure (number 3)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure4:
 final structure (number 4)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure5:
 ElementBuffer insertUpdate: second insertion (number 19)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure5:
 ElementBuffer insertUpdate: second insertion (number 22)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure5:
 ElementBuffer insertUpdate: second insertion (number 29)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure5:
 ElementBuffer insertUpdate: second insertion (number 30)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure5:
 ElementBuffer insertUpdate: second insertion (number 31)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 19)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 23)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 26)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 29)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 33)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 34)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: fourth insertion (number 35)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 31)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 34)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 41)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 42)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 43)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 44)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.ElementStructure8:
 ElementBuffer insertUpdate: second insertion (number 45)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument1:
 second doc event (number 8)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument2:
 second doc event (number 4)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create fifth leaf element (number 1)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create fifth leaf element (number 2)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create fifth leaf element (number 5)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create fourth leaf element (number 1)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create fourth leaf element (number 2)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create fourth leaf element (number 4)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create sixth leaf element (number 1)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create sixth leaf element (number 2)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create sixth leaf element (number 5)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create sixth leaf element (number 6)
FAIL: 
gnu.testlet.javax.swing.text.DefaultStyledDocument.ElementBuffer.StyledDocument3:
 create 

Re: OSGi TCK

2006-03-31 Thread Philippe Laporte

Dalibor Topic wrote:


On Wed, 2006-03-29 at 23:51 +0200, Philippe Laporte wrote:

 


You already pass our internal suite.
   



Cool.

 

I'd personally like to see the Biss-TVT AWT rescucitated. The thing 
draws on the Linux frame buffer without GTK. This is great for embedded. 
   



You may also want to take the Qt4 peers and make them work with Qtopia
on FBs. That might be simpler.
 


I can't go down the Qt road...

 


Is there a licensing hurdle here?
   



Not really. If you want the old Kaffe/Biss/Transvirtual AWT code merged
into GNU Classpath, then you need to contact all the copyright owners to
assign their copyrights to the FSF. 


That may be a bit of work, though. and you'd still need to fix the old
Kaffe AWT code to work with different peer model in GNU Classpath, among
other things. 


I am not saying it's impossible, but no one who embarked on that
adventure came back with a fully working patch yet.
 


Will look into this over time.




Re: OSGi TCK

2006-03-31 Thread Philippe Laporte

Tom Tromey wrote:


Dalibor == Dalibor Topic [EMAIL PROTECTED] writes:
   



 

I'd personally like to see the Biss-TVT AWT rescucitated. The thing 
draws on the Linux frame buffer without GTK. This is great for embedded. 
 



Dalibor You may also want to take the Qt4 peers and make them work with Qtopia
Dalibor on FBs. That might be simpler.

There's also Odonata: http://odonata.tangency.co.uk/

Another viable plan might be to write very minimal framebuffer peers
and then use the swing-based awt.  This is a work in progress though.
 


I support it! :-)




Re: jMemorize - exception in JTable code: Fixed, but JFreeChart internal problem follows.

2006-03-31 Thread Roman Kennke
Hi Audrius,

 Unfortunately, this brings us to the second 
 exception, related to the JFreeChart:
 
 java.lang.ClassCastException: gnu/java/awt/peer/gtk/GdkGraphics
 Probably our JFreeChart experts could look at this.

This is caused by missing support for Graphics2D. Try building and
running with cairo.

/Roman





Re: Green threads - some experience

2006-03-31 Thread Clemens Eisserer
 For example, on Linux where each POSIX thread is a cloned process, it's
 Linux's fault (not the JVM's fault) if that doesn't scale well. For example,
 other OS's don't have such heavyweight threads. FreeBSD's KSE's are an
 example of a better tradeoff using M:N user:kernel threading.

It seems you are some years behind actual development.
The threading model you describe was used till linux-2.4, since 2.6
NPTL is used instead which outperforms almost everything else.

lg Clemens



Re: jMemorize - exception in JTable code: Fixed, but JFreeChart internal problem follows.

2006-03-31 Thread Robert Schuster
Hey Audrius,
thanks for fixing this. Here is how jMemorize looks when using the cairo based
Graphics2D.

http://page.mi.fu-berlin.de/~rschuste/jMemorize-2006-03-31.png

configure with --enable-gtk-cairo and then run with:

jamvm -Dgnu.java.awt.peer.gtk.Graphics=Graphics2D -jar jMemorize-0.9.2.jar

It will be slow, there are some layout problems (one has to move the splitpane
dividers around) and the custom graphic in the upper frame is missing but it
starts. :)

I am not sure where this comes from but I find that our Free Swing apps look
very neat. Is there something special with our fonts?!?

cya
Robert

Roman Kennke wrote:
 Hi Audrius,
 
 
Unfortunately, this brings us to the second 
exception, related to the JFreeChart:

java.lang.ClassCastException: gnu/java/awt/peer/gtk/GdkGraphics
Probably our JFreeChart experts could look at this.
 
 
 This is caused by missing support for Graphics2D. Try building and
 running with cairo.
 
 /Roman
 
 
 
 


signature.asc
Description: OpenPGP digital signature


Re: jMemorize - exception in JTable code: Fixed, but JFreeChart internal problem follows.

2006-03-31 Thread Roman Kennke
Hi Robert,

 I am not sure where this comes from but I find that our Free Swing apps look
 very neat. Is there something special with our fonts?!?

Yes. In constrast to Sun's JDK, we use the system fonts and the system
font settings, which is normally antialiased and optimized for LCD when
running on lcd screen. Sun paints its fonts un-anti-aliased thus looks
quite bad. However, you can turn on font-antialiasing using the
RenderingHints class. It's a bit tricky to do this application wide
though... (on the downside, I think classpath ignores the RenderingHints
altogether).

/Roman




Re: jMemorize - exception in JTable code: Fixed, but JFreeChart internal problem follows.

2006-03-31 Thread Mark Wielaard
On Thu, 2006-03-30 at 23:06 +0100, David Gilbert wrote:
 I think many applications are going to fail on our implementation until 
 we get good Graphics2D support into our JComponent (many custom look and 
 feel implementations rely on it, for starters).

Agreed. Most of the things I am testing on top of our free swing do
actually work till they try using a Graphics2D environment. And our
current --enable-gtk-cairo/-Dgnu.java.awt.peer.gtk.Graphics=Graphics2D
implementation is too fragile to be really usable. There is a real plan
to get to a fully supported Graphics2D world:
http://developer.classpath.org/mediation/ClasspathGraphicsImagesText

But as David has shown we actually can get pretty nice results already
with a quick-and-dirty partial implementation based on
cairo/java-gnome: http://www.object-refinery.com/jfreechart/free.html

This is really an area were some experimentation with the various
implementation strategies can be helpful.

Cheers,

Mark


signature.asc
Description: This is a digitally signed message part


Re: jMemorize - exception in JTable code: Fixed, but JFreeChart internal problem follows.

2006-03-31 Thread Mark Wielaard
On Fri, 2006-03-31 at 15:55 +0200, Roman Kennke wrote:
 However, you can turn on font-antialiasing using the
 RenderingHints class. It's a bit tricky to do this application wide
 though... (on the downside, I think classpath ignores the
 RenderingHints altogether). 

Ironically this is how I have seen a couple of applications fail. The
only reason they try casting to a Graphics2D object in their paint()
method is to set the RenderingHints to get anti-aliasing. Such
applications do work with the --enable-gtk-cairo
-Dgnu.java.awt.peer.gtk.Graphics=Graphics2D trick since then we accept
the cast and just ignore the hint :)

Cheers,

Mark


signature.asc
Description: This is a digitally signed message part


Re: Green threads - some experience

2006-03-31 Thread Archie Cobbs

Clemens Eisserer wrote:

For example, on Linux where each POSIX thread is a cloned process, it's
Linux's fault (not the JVM's fault) if that doesn't scale well. For example,
other OS's don't have such heavyweight threads. FreeBSD's KSE's are an
example of a better tradeoff using M:N user:kernel threading.


It seems you are some years behind actual development.
The threading model you describe was used till linux-2.4, since 2.6
NPTL is used instead which outperforms almost everything else.


Good to hear that :-)

-Archie

__
Archie Cobbs  *CTO, Awarix*  http://www.awarix.com



[Bug inetlib/26960] New: IP_TOS, SO_OOBINLINE, SO_BROADCAST not supported

2006-03-31 Thread johnandtina at byu dot net
The values SocketOptions.IP_TOS, SocketOptions.SO_OOBLINE,
SocketOptions.SO_BROADCAST are not supported in
VMPlainSocketImpl.[get|set]Option.  So, java.net.Socket.[get|set]TrafficClass
and java.net.DatagramSocket.[get|set]Broadcast throw an SocketException.

These just need support in native/jni/java-net/javanet.[hc]
_javanet_[get|set]_option and native/target/generic/target_generic_network.h. 
I'd give you my fixes, but I'm 'tainted'.


Index: javax/swing/plaf/basic/BasicTextAreaUI.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/plaf/basic/BasicTextAreaUI.java,v
retrieving revision 1.6
diff -u -r1.6 BasicTextAreaUI.java
--- javax/swing/plaf/basic/BasicTextAreaUI.java	31 Oct 2005 21:29:52 -	1.6
+++ javax/swing/plaf/basic/BasicTextAreaUI.java	31 Mar 2006 15:17:58 -
@@ -45,9 +45,11 @@
 import javax.swing.JTextArea;
 import javax.swing.UIDefaults;
 import javax.swing.plaf.ComponentUI;
+import javax.swing.text.Document;
 import javax.swing.text.Element;
 import javax.swing.text.PlainView;
 import javax.swing.text.View;
+import javax.swing.text.ViewFactory;
 import javax.swing.text.WrappedPlainView;
 
 public class BasicTextAreaUI extends BasicTextUI
@@ -108,6 +110,9 @@
 JTextArea comp = (JTextArea)getComponent();
 if (ev.getPropertyName() == lineWrap
 || ev.getPropertyName() == wrapStyleWord)
-  modelChanged();
+  {
+// Changes the View (without modifying the document or it's listeners).
+setView(create(textComponent.getDocument().getDefaultRootElement()));
+  }
   }
 }


signature.asc
Description: OpenPGP digital signature


Re: Green threads - some experience

2006-03-31 Thread Ian Rogers

Archie Cobbs wrote:

IMHO using POSIX threads is the only right answer for a multi-platform
JVM. You have no other choice except to leave it up to the specific
platform to then implement POSIX threads efficiently.

For example, on Linux where each POSIX thread is a cloned process, it's
Linux's fault (not the JVM's fault) if that doesn't scale well. For 
example,

other OS's don't have such heavyweight threads. FreeBSD's KSE's are an
example of a better tradeoff using M:N user:kernel threading.
I agree with you. I think it's always the case that Java threads are 
going to be better than POSIX threads though, as with some commodity 
processors, in particular I'm thinking of Cell, you no longer have a 
shared memory model. In such a situation you could use a distributed 
JVM, such as JESSICA2 - that's built on top of Kaffe :-). So whilst 
implementing a JVM assuming POSIX threads is a good idea to run on many 
platforms, there are legitimate reasons why you may want to be flexible 
and not assume a 1-to-1 mapping of Java threads to POSIX threads, and of 
course avoid native code.


Regards,

Ian



[Bug swing/26843] JTextArea with lineWrap=true - up/down movement broken

2006-03-31 Thread thebohemian at gmx dot net


--- Comment #2 from thebohemian at gmx dot net  2006-03-31 16:09 ---
Now that PR 26842 is fixed I see that the real problem is that up and down
movement is broken. There are all kind of glitches like skipping lines when
pressing down, jumping between two positions and the exception mentioned in
comment #1.


Index: javax/swing/DefaultListSelectionModel.java
===
RCS file: /sources/classpath/classpath/javax/swing/DefaultListSelectionModel.java,v
retrieving revision 1.26
diff -u -r1.26 DefaultListSelectionModel.java
--- javax/swing/DefaultListSelectionModel.java	28 Feb 2006 21:10:14 -	1.26
+++ javax/swing/DefaultListSelectionModel.java	31 Mar 2006 09:45:22 -
@@ -539,20 +539,47 @@
*/
   public void clearSelection()
   {
-oldSel = sel.clone();
-int sz = sel.size();
-sel.clear();
-if (sel.equals(oldSel) == false)
-  fireValueChanged(0, sz, valueIsAdjusting);
+// Find the selected interval.
+int from = sel.nextSetBit(0);
+if (from  0)
+  return; // Empty selection - nothing to do.
+int to = from;
+
+int i;
+
+Up: for (i = from; i=0; i=sel.nextSetBit(i+1))
+  to = i;
+
+fireValueChanged(from, to, valueIsAdjusting);
   }
   
   /**
-   * Clears the current selection and marks a given interval as
-   * selected. If the current selection mode is
-   * codeSINGLE_SELECTION/code only the index codeindex2/code is
-   * selected.
-   *
-   * @param index0 The low end of the new selection 
+   * Fire the change event, covering the difference between the two sets.
+   * 
+   * @param current the current set
+   * @param x the previous set, the object will be reused.
+   */
+  private void fireDifference(BitSet current, BitSet x)
+  {
+x.xor(current);
+int from = x.nextSetBit(0);
+if (from  0)
+  return; // No difference.
+int to = from;
+int i;
+
+for (i = from; i = 0; i = x.nextSetBit(i+1))
+  to = i;
+
+fireValueChanged(from, to, valueIsAdjusting);
+  }
+  
+  /**
+   * Clears the current selection and marks a given interval as selected. If
+   * the current selection mode is codeSINGLE_SELECTION/code only the
+   * index codeindex2/code is selected.
+   * 
+   * @param index0 The low end of the new selection
* @param index1 The high end of the new selection
*/
   public void setSelectionInterval(int index0, int index1)
@@ -560,7 +587,7 @@
 if (index0 == -1 || index1 == -1)
   return;
 
-oldSel = sel.clone();
+BitSet oldSel = (BitSet) sel.clone();
 sel.clear();
 if (selectionMode == SINGLE_SELECTION)
   index0 = index1;
@@ -571,8 +598,8 @@
 // update the anchorSelectionIndex and leadSelectionIndex variables
 setAnchorSelectionIndex(index0);
 leadSelectionIndex=index1;
-if (sel.equals(oldSel) == false)
-  fireValueChanged(lo, hi, valueIsAdjusting);
+
+fireDifference(sel, oldSel);
   }
 
   /**
Index: javax/swing/text/GapContent.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/text/GapContent.java,v
retrieving revision 1.43
diff -u -r1.43 GapContent.java
--- javax/swing/text/GapContent.java	29 Mar 2006 14:52:35 -	1.43
+++ javax/swing/text/GapContent.java	31 Mar 2006 15:17:58 -
@@ -644,10 +644,11 @@
 System.arraycopy(addItems, 0, buffer, gapStart, addSize);
 
 // Position objects having their mark at the end of the gap
-// (results in an offset of 0) should be moved down because
-// the size of the gap will decrease by addSize and the offsets
-// will increase by the same amount and the latter should not happen.
-resetMarksAtZero();
+// (results in an offset equal to gapStart) should be moved down
+// because the size of the gap will decrease by addSize and the
+// offsets will increase by the same amount and the latter should
+// not happen.
+setPositionsInRange(gapEnd, 0, gapStart);
 
 gapStart += addSize;
   }
-- 
   Summary: IP_TOS, SO_OOBINLINE, SO_BROADCAST not supported
   Product: classpath
   Version: 0.90
Status: UNCONFIRMED
  Severity: normal
  Priority: P3
 Component: inetlib
AssignedTo: dog at gnu dot org
ReportedBy: johnandtina at byu dot net


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=26960



___
Bug-classpath mailing list
Bug-classpath@gnu.org
http://lists.gnu.org/mailman/listinfo/bug-classpath


[Bug inetlib/26960] IP_TOS, SO_OOBINLINE, SO_BROADCAST not supported

2006-03-31 Thread johnandtina at byu dot net


--- Comment #1 from johnandtina at byu dot net  2006-03-31 15:09 ---
Oh, I forgot to mention that it's not that I use these mostly esoteric socket
options, but MINA from Apache Directory Server calls all the 'get's to retrieve
default values (in
org.apache.mina.transport.socket.nio.support.SocketSessionConfigImpl and
org.apache.mina.transport.socket.nio.support.DatagramSessionConfigImpl).


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=26960



___
Bug-classpath mailing list
Bug-classpath@gnu.org
http://lists.gnu.org/mailman/listinfo/bug-classpath


FYI: fix broken Caret behavior in JTextAreas with lineWrap=true

2006-03-31 Thread Robert Schuster
Hi,
this patch fixes PR 26842[0]. The fix to GapContent made another drawing problem
visible which occured because document listeners have been registered twice. I
prevented that by not indicating that the document has changed when someone
changes the lineWrap or wrapStyleWord property and only update the view.

The ChangeLog:

2006-03-31  Robert Schuster  [EMAIL PROTECTED]

* javax/swing/text/GapContent.java:
(replace): Move all Position instances from gap's end to
it's start before increasing the gap start.
* javax/swing/plaf/basic/BasicTextAreaUI.java:
(propertyChanged): Update the view only instead of
indicating a document change.

[0] - http://gcc.gnu.org/bugzilla/show_bug.cgi?id=26842
Index: javax/swing/text/GapContent.java
===
RCS file: /cvsroot/classpath/classpath/javax/swing/text/GapContent.java,v
retrieving revision 1.43
diff -u -r1.43 GapContent.java
--- javax/swing/text/GapContent.java	29 Mar 2006 14:52:35 -	1.43
+++ javax/swing/text/GapContent.java	31 Mar 2006 15:17:58 -
@@ -644,10 +644,11 @@
 System.arraycopy(addItems, 0, buffer, gapStart, addSize);
 
 // Position objects having their mark at the end of the gap
-// (results in an offset of 0) should be moved down because
-// the size of the gap will decrease by addSize and the offsets
-// will increase by the same amount and the latter should not happen.
-resetMarksAtZero();
+// (results in an offset equal to gapStart) should be moved down
+// because the size of the gap will decrease by addSize and the
+// offsets will increase by the same amount and the latter should
+// not happen.
+setPositionsInRange(gapEnd, 0, gapStart);
 
 gapStart += addSize;
   }
-- 

thebohemian at gmx dot net changed:

   What|Removed |Added

 Status|NEW |ASSIGNED
   Last reconfirmed|2006-03-24 12:24:41 |2006-03-31 16:09:36
   date||
Summary|JTextArea with lineWrap=true|JTextArea with lineWrap=true
   |- selecting text across |- up/down movement broken
   |multiple lines cause|
   |IllegalArgumentException|


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=26843



___
Bug-classpath mailing list
Bug-classpath@gnu.org
http://lists.gnu.org/mailman/listinfo/bug-classpath


Re: Green threads - some experience

2006-03-31 Thread Archie Cobbs

Ian Rogers wrote:

Archie Cobbs wrote:

IMHO using POSIX threads is the only right answer for a multi-platform
JVM. You have no other choice except to leave it up to the specific
platform to then implement POSIX threads efficiently.

For example, on Linux where each POSIX thread is a cloned process, it's
Linux's fault (not the JVM's fault) if that doesn't scale well. For 
example,

other OS's don't have such heavyweight threads. FreeBSD's KSE's are an
example of a better tradeoff using M:N user:kernel threading.
I agree with you. I think it's always the case that Java threads are 
going to be better than POSIX threads though, as with some commodity 
processors, in particular I'm thinking of Cell, you no longer have a 
shared memory model. In such a situation you could use a distributed 
JVM, such as JESSICA2 - that's built on top of Kaffe :-). So whilst 
implementing a JVM assuming POSIX threads is a good idea to run on many 
platforms, there are legitimate reasons why you may want to be flexible 
and not assume a 1-to-1 mapping of Java threads to POSIX threads, and of 
course avoid native code.


You're right.. there is a subtlety here I was glossing over.

When referring to threads above, I guess I meant things that actually
need to consume C runtime stack. For example, if you have code that
invokes read(2), this code needs to have it's own C runtime stack and
needs a real O/S-supplied thread to sleep with. Any time you invoke
JNI native code, you'll also need a real thread and runtime stack.

On the other hand, Java threads are entirely virtual and their stacks
don't have to correspond 1:1 to C runtime stacks (although it surely
is convenient to do it that way). I don't know which JVMs make this
distinction. You would have to lend a real thread to a Java thread
anytime it invokes native code. But you could re-use that thread once
the thread returned to Java code; if the thread called back into Java
code from within the native method, you could also return the real thread
to the thread pool, but the chunk of C runtime stack that supported the
native method call would have to be saved somewhere of course. You'd
need a lot of longjmp() or setcontext() magic to do this.

The upshot would be that you only use real threads when absolutely
required, e.g., you're making a blocking system call, and Java threads
would be very lightweight (corresponding merely to linked lists of
Java stack frame structures, or whatever).

-Archie

__
Archie Cobbs  *CTO, Awarix*  http://www.awarix.com



New japize option

2006-03-31 Thread Stuart Ballard
I added a new option to Japize to allow excluding svuid information
for a particular set of packages or classes. I'm using it on my
scripts but I'm mentioning it here because you might want to use it
for the runs on Builder too.

japize as xxx packages +whatever -whatever -javax.swing:serial

That will cause all classes in javax.swing to be emitted without
svuids, as if they weren't serializable (although the fact that they
implement java.io.Serializable will still be recorded and checked). (I
also arranged for enums to get that treatment automatically). Also,
any class that *inherits* from a class that's emitted this way will
also be emitted without a svuid, because if the superclass isn't
serialization-compatible, the subclass pretty much can't be either.

Anyone have any particular strong feelings on whether I ought to be
specifying the whole javax.swing package or just, eg, subclasses of
JComponent? And whether there are any particular bits that should
*not* be excluded? (I don't know where to find the Sun documentation
that says serialization of Swing isn't supported so I'm not sure
exactly what it applies to...)

Stuart.
--
http://sab39.dev.netreach.com/



Re: New japize option

2006-03-31 Thread Stuart Ballard
On 3/31/06, Andrew John Hughes [EMAIL PROTECTED] wrote:
 I believe it's on the individual Javadoc pages for each Swing class e.g.
 on JComponent:

 'Warning: Serialized objects of this class will not be compatible with
 future Swing releases. The current serialization support is appropriate
 for short term storage or RMI between applications running the same
 version of Swing.'

Yuck, so there's no easy way to verify that it actually does apply to
*every* class in swing?

Stuart.

--
http://sab39.dev.netreach.com/



[commit-cp] classpath ./ChangeLog javax/swing/DefaultComboB...

2006-03-31 Thread David Gilbert
CVSROOT:/sources/classpath
Module name:classpath
Branch: 
Changes by: David Gilbert [EMAIL PROTECTED]   06/03/31 09:45:48

Modified files:
.  : ChangeLog 
javax/swing: DefaultComboBoxModel.java 

Log message:
2006-03-31  David Gilbert  [EMAIL PROTECTED]

Fixes bug #26951
* javax/swing/DefaultComboBoxModel.java
(DefaultComboBoxModel(Vector)): Call getSize() instead of
vector.size(),
(addElement): Call list.addElement() rather than list.add(), and only
update selected item if it is currently null,
(removeElementAt): Update selected item, then remove the element.
--

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6957tr2=1.6958r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/swing/DefaultComboBoxModel.java.diff?tr1=1.14tr2=1.15r1=textr2=text




[commit-cp] classpath javax/swing/DefaultListSelectionModel...

2006-03-31 Thread Audrius Meskauskas
CVSROOT:/sources/classpath
Module name:classpath
Branch: 
Changes by: Audrius Meskauskas [EMAIL PROTECTED]  06/03/31 10:13:16

Modified files:
javax/swing: DefaultListSelectionModel.java JTable.java 
.  : ChangeLog 
javax/swing/plaf/basic: BasicTableUI.java 

Log message:
2006-03-31  Audrius Meskauskas  [EMAIL PROTECTED]

* javax/swing/DefaultListSelectionModel.java (fireDifference):
New method. (clearSelection): Rewritten. (setSelectionInterval):
Fire the difference between current and new selection.
* javax/swing/JTable.java (columnSelectionChanged, valueChanged):
Only repaint the region, where selection has been changed.
* javax/swing/plaf/basic/BasicTableUI.java
(TableAction.actionPerformed): Do not change the column selection
when only row selection change is wanted (and in reverse) and
do not call the repaint() here.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/swing/DefaultListSelectionModel.java.diff?tr1=1.26tr2=1.27r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/swing/JTable.java.diff?tr1=1.91tr2=1.92r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6958tr2=1.6959r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/swing/plaf/basic/BasicTableUI.java.diff?tr1=1.47tr2=1.48r1=textr2=text




[commit-cp] classpath java/util/jar/Attributes.java gnu/jav...

2006-03-31 Thread Raif S. Naffah
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Raif S. Naffah [EMAIL PROTECTED]  06/03/31 12:24:09

Modified files:
java/util/jar  : Attributes.java 
gnu/java/util/jar: JarUtils.java 
.  : ChangeLog 
tools/gnu/classpath/tools/jarsigner: SFHelper.java 

Log message:
2006-03-31  Raif S. Naffah  [EMAIL PROTECTED]

* tools/gnu/classpath/tools/jarsigner/SFHelper.java (updateEntry): Use
Attributes.putValue(String,String).
(finishSigning): Likewise.
* gnu/java/util/jar/JarUtils.java (MANIFEST_VERSION): New constant.
(SIGNATURE_VERSION): Likewise.
(readSFManifest): Use local string constant.
(readMainSection): Likewise.
(readVersionInfo): Likewise.
* java/util/jar/Attributes.java (MANIFEST_VERSION):
Redefined using JarUtils constant.
(SIGNATURE_VERSION): Likewise.
(putValue(Name,String)): Made it private.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/java/util/jar/Attributes.java.diff?tr1=1.14tr2=1.15r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/gnu/java/util/jar/JarUtils.java.diff?tr1=1.1tr2=1.2r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6959tr2=1.6960r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/tools/gnu/classpath/tools/jarsigner/SFHelper.java.diff?tr1=1.1tr2=1.2r1=textr2=text




[commit-cp] classpath javax/swing/JComponent.java ./ChangeLog

2006-03-31 Thread Roman Kennke
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Roman Kennke [EMAIL PROTECTED]06/03/31 12:33:06

Modified files:
javax/swing: JComponent.java 
.  : ChangeLog 

Log message:
2006-03-31  Roman Kennke  [EMAIL PROTECTED]

* javax/swing/JComponent.java
(paintChildren): Split up in two cases, depending on the
optimizedDrawingEnabled flag.
(paintChildrenWithOverlap): New method. Paints children when
not optimizedDrawingEnabled. This implements better painting
algorithm for overlapping components, so that the painted
regions are minimized.
(paintChildrenOptimized): New method. Paints children when
when optimizedDrawingEnabled. This implements a painting
algorithm that is optimized for the case when all children
are guaranteed to be tiled.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/swing/JComponent.java.diff?tr1=1.109tr2=1.110r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6960tr2=1.6961r1=textr2=text




[commit-cp] classpath ./ChangeLog tools/gnu/classpath/tools...

2006-03-31 Thread Raif S. Naffah
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Raif S. Naffah [EMAIL PROTECTED]  06/03/31 13:41:49

Modified files:
.  : ChangeLog 
tools/gnu/classpath/tools/jarsigner: Main.java 

Log message:
2006-04-01  Raif S. Naffah  [EMAIL PROTECTED]

* tools/gnu/classpath/tools/jarsigner/Main.java (setupCommonParams):
Check for null jar-file argument.
(setupSigningParams): Check for null alias argument.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6961tr2=1.6962r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/tools/gnu/classpath/tools/jarsigner/Main.java.diff?tr1=1.3tr2=1.4r1=textr2=text




[commit-cp] classpath ./ChangeLog javax/swing/JTextField.java

2006-03-31 Thread Roman Kennke
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Roman Kennke [EMAIL PROTECTED]06/03/31 15:03:57

Modified files:
.  : ChangeLog 
javax/swing: JTextField.java 

Log message:
2006-03-31  Roman Kennke  [EMAIL PROTECTED]

* javax/swing/JTextField.java
(fireActionPerformed): Put the textfields text in the action
instead of the action name.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6962tr2=1.6963r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/swing/JTextField.java.diff?tr1=1.30tr2=1.31r1=textr2=text




[commit-cp] classpath ./ChangeLog javax/swing/text/GapConte...

2006-03-31 Thread Robert Schuster
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Robert Schuster [EMAIL PROTECTED] 06/03/31 15:38:09

Modified files:
.  : ChangeLog 
javax/swing/text: GapContent.java 
javax/swing/plaf/basic: BasicTextAreaUI.java 

Log message:
2006-03-31  Robert Schuster  [EMAIL PROTECTED]

* javax/swing/text/GapContent.java:
(replace): Move all Position instances from gap's end to
it's start before increasing the gap start.
* javax/swing/plaf/basic/BasicTextAreaUI.java:
(propertyChanged): Update the view only instead of
indicating a document change.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6963tr2=1.6964r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/swing/text/GapContent.java.diff?tr1=1.43tr2=1.44r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/swing/plaf/basic/BasicTextAreaUI.java.diff?tr1=1.6tr2=1.7r1=textr2=text




[commit-cp] classpath ./ChangeLog native/jni/gtk-peer/gnu_j...

2006-03-31 Thread Lillian Angel
CVSROOT:/sources/classpath
Module name:classpath
Branch: 
Changes by: Lillian Angel [EMAIL PROTECTED]   06/03/31 18:57:07

Modified files:
.  : ChangeLog 
native/jni/gtk-peer: gnu_java_awt_peer_gtk_GtkCanvasPeer.c 
include: gnu_java_awt_peer_gtk_GtkCanvasPeer.h 
gnu/java/awt/peer/gtk: GtkCanvasPeer.java 

Log message:
2006-03-31  Lillian Angel  [EMAIL PROTECTED]

PR classpath/26924
* gnu/java/awt/peer/gtk/GtkCanvasPeer.java
(realize): New native function.
* include/gnu_java_awt_peer_gtk_GtkCanvasPeer.h:
Added new function declaration.
* native/jni/gtk-peer/gnu_java_awt_peer_gtk_GtkCanvasPeer.c
(realize): New function.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6964tr2=1.6965r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/native/jni/gtk-peer/gnu_java_awt_peer_gtk_GtkCanvasPeer.c.diff?tr1=1.11tr2=1.12r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/include/gnu_java_awt_peer_gtk_GtkCanvasPeer.h.diff?tr1=1.3tr2=1.4r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/gnu/java/awt/peer/gtk/GtkCanvasPeer.java.diff?tr1=1.16tr2=1.17r1=textr2=text




[commit-cp] classpath ./ChangeLog javax/swing/JTable.java

2006-03-31 Thread Audrius Meskauskas
CVSROOT:/sources/classpath
Module name:classpath
Branch: 
Changes by: Audrius Meskauskas [EMAIL PROTECTED]  06/03/31 21:10:09

Modified files:
.  : ChangeLog 
javax/swing: JTable.java 

Log message:
2006-03-31  Audrius Meskauskas  [EMAIL PROTECTED]

* javax/swing/JTable.java (columnSelectionChanged):
Treat second repaint parameter as width.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6965tr2=1.6966r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/swing/JTable.java.diff?tr1=1.92tr2=1.93r1=textr2=text




[commit-cp] classpath ./ChangeLog java/awt/Component.java

2006-03-31 Thread Lillian Angel
CVSROOT:/sources/classpath
Module name:classpath
Branch: 
Changes by: Lillian Angel [EMAIL PROTECTED]   06/03/31 21:41:14

Modified files:
.  : ChangeLog 
java/awt   : Component.java 

Log message:
2006-03-31  Lillian Angel  [EMAIL PROTECTED]

* java/awt/Component.java
(translateEvent): oldKey should be the value of the
key char.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6966tr2=1.6967r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/java/awt/Component.java.diff?tr1=1.109tr2=1.110r1=textr2=text




[commit-cp] classpath ./ChangeLog javax/imageio/plugins/jpe...

2006-03-31 Thread Thomas Fitzsimmons
CVSROOT:/sources/classpath
Module name:classpath
Branch: 
Changes by: Thomas Fitzsimmons [EMAIL PROTECTED]  06/03/31 21:52:30

Modified files:
.  : ChangeLog 
javax/imageio/plugins/jpeg: JPEGHuffmanTable.java 
JPEGQTable.java 

Log message:
2006-03-31  Thomas Fitzsimmons  [EMAIL PROTECTED]

* javax/imageio/plugins/jpeg/JPEGHuffmanTable.java: Eliminate
unnecessary copying.
* javax/imageio/plugins/jpeg/JPEGQTable.java: Likewise.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6967tr2=1.6968r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/imageio/plugins/jpeg/JPEGHuffmanTable.java.diff?tr1=1.2tr2=1.3r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/imageio/plugins/jpeg/JPEGQTable.java.diff?tr1=1.1tr2=1.2r1=textr2=text




[commit-cp] classpath javax/swing/DefaultListSelectionModel...

2006-03-31 Thread Audrius Meskauskas
CVSROOT:/sources/classpath
Module name:classpath
Branch: 
Changes by: Audrius Meskauskas [EMAIL PROTECTED]  06/03/31 22:03:45

Modified files:
javax/swing: DefaultListSelectionModel.java JTable.java 
.  : ChangeLog 

Log message:
2006-03-31  Audrius Meskauskas  [EMAIL PROTECTED]

* javax/swing/JTable.java (columnSelectionChanged):
Removed print statement.
* javax/swing/DefaultListSelectionModel.java
(addSelectionInterval, removeSelectionInterval):
Fire the difference between selection. (setLeadSelectionIndex):
Fire the difference and mark current and previous lead
selection indexes for repaint.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/swing/DefaultListSelectionModel.java.diff?tr1=1.27tr2=1.28r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/javax/swing/JTable.java.diff?tr1=1.93tr2=1.94r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6968tr2=1.6969r1=textr2=text




[commit-cp] classpath ./ChangeLog lib/Makefile.am lib/gen-c...

2006-03-31 Thread Tom Tromey
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: 
Changes by: Tom Tromey [EMAIL PROTECTED]  06/03/31 22:42:19

Modified files:
.  : ChangeLog 
lib: Makefile.am gen-classlist.sh.in 
 split-for-gcj.sh 

Log message:
* lib/split-for-gcj.sh: Updated for multi-field format.
* lib/Makefile.am (CLEANFILES): Added classes.2.
* lib/gen-classlist.sh.in (GCJ): Removed.  Create classes.1 and
classes.2 using multiple fields.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/ChangeLog.diff?tr1=1.6969tr2=1.6970r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/lib/Makefile.am.diff?tr1=1.113tr2=1.114r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/lib/gen-classlist.sh.in.diff?tr1=1.33tr2=1.34r1=textr2=text
http://cvs.savannah.gnu.org/viewcvs/classpath/classpath/lib/split-for-gcj.sh.diff?tr1=1.7tr2=1.8r1=textr2=text